@@ -35,12 +35,10 @@
 #include <mgui/sdk/ioblock.h>
 #include <mgui/sdk/textview.h>  // AppendCommandText()
 #include <mgui/ffviewer.h>
-#include <mgui/prefs.h> // PreferencesPath()
 
 #include <mbase/project/table.h>
 
 #include <mlib/filesystem.h>
-#include <mlib/string.h>
 #include <mlib/read_stream.h> // ReadAllStream()
 #include <mlib/sdk/system.h> // GetClockTime()
 #include <mlib/gettext.h>
@@ -148,7 +146,15 @@ class SubtitleWrapper
      Cairo::FontOptions  fOpt;  // поэтому убираем сглаживание
 
     void SetAntialias(Cairo::Antialias alias_type)
-    { 
+    {
+        // не меняем сглаживание, потому что:
+        // 1) все равно приходится дискретизировать, DiscreteByAlpha()
+        // 2) побочный эффект - в некоторых случаях настроек шрифтов (системным образом,
+        //  точно не определил) помимо антиалиасинга изменяется ширина результата рендеринга,
+        //  что выражается визуально, в расхождении текста и его субкартинки (в dvd-меню)
+        //  => ошибка; об этом же говорит справка к pango_cairo_context_set_font_options()
+        //  (не знаю, что конкретно на это влияет,- один из атрибутов _cairo_font_options)
+        return; 
         fOpt.set_antialias(alias_type);
         pCont->set_cairo_font_options(fOpt);
     }
@@ -524,9 +530,64 @@ static int PadSize(int free_space)
     return (free_space/2) & ~0x1;
 }
 
+bool IsVersionGE(const TripleVersion& big_v, const TripleVersion& v)
+{
+    bool cmp_res;
+    if( CompareComponent(v.major, big_v.major, cmp_res) ||
+        CompareComponent(v.minor, big_v.minor, cmp_res) || 
+        CompareComponent(v.micro, big_v.micro, cmp_res)    )
+        return cmp_res;
+
+    // версии равны
+    return true;
+}
+
+static std::string FFSizeOption(const Point& sz)
+{
+    return boost::format("-s %1%x%2%") % sz.x % sz.y % bf::stop;
+}
+
+static std::string FFImgSizeOption(const Point& sz, int val, bool is_left_right)
+{
+    Point img_sz = is_left_right ? Point(sz.x - 2*val, sz.y) : Point(sz.x, sz.y - 2*val);
+    return FFSizeOption(img_sz);
+}
+
+static std::string FFPadFilterSet(const Point& sz, int val, bool is_left_right)
+{
+    int x = 0, y = 0;
+    if( is_left_right )
+        x = val;
+    else
+        y = val;
+
+    return boost::format("%1% -vf pad=%2%:%3%:%4%:%5%:black") 
+        % FFImgSizeOption(sz, val, is_left_right) % sz.x % sz.y % x % y % bf::stop;
+}
+
+static std::string FFSizeSet(const Point& sz, int val, 
+                                  bool is_left_right, bool is_vf)
+{
+    std::string sz_str;
+    if( is_vf )
+        sz_str = FFPadFilterSet(sz, val, is_left_right);
+    else
+    {
+        const char* fmt = is_left_right ? "%1% -padleft %2% -padright %2%" : "%1% -padtop %2% -padbottom %2%" ;
+        sz_str = boost::format(fmt) % FFImgSizeOption(sz, val, is_left_right) % val % bf::stop;
+    }
+    return sz_str;
+}
+
 std::string FFmpegToDVDArgs(const std::string& out_fname, const AutoDVDTransData& atd, bool is_pal,
                             const DVDTransData& td)
 {
+    // * предполагается после создания команды ее вызов => требуется
+    // проверка такой возможности
+    TripleVersion filter_ver = CheckFFDVDEncoding().avfilter;
+    // вместо -padX использовать -vf pad=w:h:x:y:black
+    bool is_vf = IsVersionGE(filter_ver, TripleVersion(1, 20, 0));
+
     // *
     const char* target =  is_pal ? "pal" : "ntsc" ;
     Point DVDDimension(DVDDims dd, bool is_pal);
@@ -547,22 +608,20 @@ std::string FFmpegToDVDArgs(const std::string& out_fname, const AutoDVDTransData
     DPoint asp = FitInto1(dst_asp, ChangePoint<double>(atd.srcAspect));
 
     Point img_sz(asp.x * sz.x, asp.y * sz.y);
-    std::string sz_str = boost::format("-s %1%x%2%") % sz.x % sz.y % bf::stop;
+    std::string sz_str = FFSizeOption(sz);
     if( img_sz.x < sz.x )
     {
         // справа и слева
         int val = PadSize(sz.x - img_sz.x);
         if( val )
-            sz_str = boost::format("-s %1%x%2% -padleft %3% -padright %3%") 
-                % (sz.x - 2*val) % sz.y % val % bf::stop;
+            sz_str = FFSizeSet(sz, val, true, is_vf);
     }
     else if( img_sz.y < sz.y )
     {
         // сверху и снизу
         int val = PadSize(sz.y - img_sz.y);
         if( val )
-            sz_str = boost::format("-s %1%x%2% -padtop %3% -padbottom %3%")
-                % sz.x % (sz.y - 2*val) % val % bf::stop;
+            sz_str = FFSizeSet(sz, val, false, is_vf);
     }
     // * дополнительные аудио
     std::string add_audio_str;
@@ -573,11 +632,7 @@ std::string FFmpegToDVDArgs(const std::string& out_fname, const AutoDVDTransData
     // * доп. опции
     std::string add_opts("-mbd rd -trellis 2 -cmp 2 -subcmp 2");
     {
-        std::string user_opts = ReadAllStream(PreferencesPath("ffmpeg_options"));
-        // только первая строка
-        size_t eol = user_opts.find_first_of("\n\r");
-        if( eol != std::string::npos )
-            user_opts = std::string(user_opts.c_str(), eol);
+        std::string user_opts = PrefContents("ffmpeg_options");
         if( !user_opts.empty() )
             add_opts += " " + user_opts;
     }
@@ -922,9 +977,33 @@ static void CheckNoCodecs(bool res)
         FFmpegError("no codec is found");
 }
 
-// conts - вывод ffmpeg -formats
-void TestFFmpegForDVDEncoding(const std::string& conts)
+int AsInt(const re::match_results& what, int idx)
 {
+    return boost::lexical_cast<int>(what.str(idx));
+}
+
+TripleVersion FindVersion(const std::string& conts, const re::pattern& ver_pat,
+                          const char* app_name, const char* target_name)
+{
+    re::match_results what;
+    if( !re::search(conts, what, ver_pat) )
+    {
+        const char* target = target_name ? target_name : app_name ;
+        Author::ApplicationError(app_name, boost::format("can't parse %1% version") % target % bf::stop);
+    }
+    return TripleVersion(AsInt(what, 1), AsInt(what, 2), AsInt(what, 3));
+}
+
+// conts - вывод ffmpeg -formats
+FFmpegVersion TestFFmpegForDVDEncoding(const std::string& conts)
+{
+    // ищем версию libavfilter
+    // пример: " libavfilter    0. 4. 0 / "
+#define RG_PADNUM RG_SPS RG_NUM
+    static re::pattern avfilter_version(RG_BW"libavfilter"RG_PADNUM"\\."RG_PADNUM"\\."RG_PADNUM" / ");
+    FFmpegVersion ff_ver;
+    ff_ver.avfilter = FindVersion(conts, avfilter_version, "ffmpeg", "libavfilter");
+
     CheckNoCodecs(CheckForCodecList(conts));
 
     static re::pattern dvd_format("^ .E dvd"RG_EW);
@@ -936,10 +1015,13 @@ void TestFFmpegForDVDEncoding(const std::string& conts)
     // по факту ffmpeg всегда использует ac3, однако mp2 тоже возможен
     static re::pattern ac3_codec("^ .EA... ac3"RG_EW);
     CheckStrippedFFmpeg(ac3_codec, conts, "ac3 audio encoder");
+
+    return ff_ver;
 }
 
-void CheckFFDVDEncoding()
+FFmpegVersion CheckFFDVDEncoding()
 {
+    FFmpegVersion ff_ver;
     // наличие полного ffmpeg
     std::string ff_formats;
     ExitData ed = PipeOutput("ffmpeg -formats", ff_formats);
@@ -966,8 +1048,9 @@ void CheckFFDVDEncoding()
             ff_formats += ff_codecs;
         }
 
-        TestFFmpegForDVDEncoding(ff_formats);
+        ff_ver = TestFFmpegForDVDEncoding(ff_formats);
     }
+    return ff_ver;
 }
 
 bool RenderMainPicture(const std::string& out_dir, Menu mn, int i)
@@ -977,8 +1060,6 @@ bool RenderMainPicture(const std::string& out_dir, Menu mn, int i)
 
     if( IsMotion(mn) )
     {
-        CheckFFDVDEncoding();
-
         if( mn->MtnData().isStillPicture )
             SaveStillMenuMpg(mn_dir, mn);
         else
