@@ -45,18 +45,18 @@
 #include <mlib/sdk/logger.h>
 #include <mlib/regex.h>
 
-#include <boost/lexical_cast.hpp>
-
 namespace Project 
 {
 
+static void AddFormatAttr(xmlpp::Element* node)
+{
+    node->set_attribute("format", IsPALProject() ? "pal" : "ntsc");
+}
+
 static xmlpp::Element* AddVideoTag(xmlpp::Element* node, bool is_4_3 = true)
 {
-    ADatabase& db = AData();
     xmlpp::Element* vnode = node->add_child("video");
-    vnode->set_attribute("format", db.PalTvSystem() ? "pal" : "ntsc");
-    //Point aspect = db.GetDefMP().DisplayAspect();
-    //vnode->set_attribute("aspect", (str::stream() << aspect.x << ":" << aspect.y).str());
+    AddFormatAttr(vnode);
     vnode->set_attribute("aspect", is_4_3 ? "4:3" : "16:9");
 
     return vnode;
@@ -670,9 +670,13 @@ static void OnTranscodePrintParse(const char* dat, int sz, const io::pos trans_t
     {
         // :KLUDGE: вроде и нецелые могут быть, но precision=0
         // как-то не в тему
-        io::pos sz = 1024 * boost::lexical_cast<io::pos>(what.str(1));
-        double per = (std::min(sz, trans_val) + trans_done)/double(trans_total);
-        Author::SetStageProgress(per);
+        // У пользователей случалось вообще не число, потому гасим возможные исключения
+        io::pos sz;
+        if( Str::GetType(sz, what.str(1).c_str()) )
+        {
+            double per = (std::min(sz * 1024, trans_val) + trans_done)/double(trans_total);
+            Author::SetStageProgress(per);
+        }
     }
 }
 
@@ -688,7 +692,6 @@ static void AuthorImpl(const std::string& out_dir)
     Author::SetStage(Author::stTRANSCODE);
     boost_foreach( VideoItem vi, AllTransVideos() )
     {
-        CheckFFDVDEncoding();
         std::string src_fname = SrcFilename(vi);
         std::string dst_fname = DVDCompliantFilename(vi, out_dir);
         // :TRICKY: отдельные видеофайлы подгоняем под DVD-формат исходя из них самих
@@ -714,7 +717,17 @@ static void AuthorImpl(const std::string& out_dir)
         if( IsToAddSubtitles(vi) )
         {
             xmlpp::Document doc;
-            xmlpp::Element* ts = doc.create_root_node("subpictures")->add_child("stream")->add_child("textsub");
+            xmlpp::Element* sp = doc.create_root_node("subpictures");
+            // определяем версию, потому что:
+            // 1) с 0.7.0 необходим доп. атрибут "format"
+            // 2) парсер dvdauthor не любит незнакомые ему атрибуты => spumux < 0.7 не работает
+            std::string help_str;
+            PipeOutput("spumux -h", help_str);
+            static re::pattern spumux_version("DVDAuthor::spumux, version "RG_NUM"\\."RG_NUM"\\."RG_NUM"\\.\n");
+            if( IsVersionGE(FindVersion(help_str, spumux_version, "spumux"), TripleVersion(0, 7, 0)) )
+                AddFormatAttr(sp);
+
+            xmlpp::Element* ts = sp->add_child("stream")->add_child("textsub");
 
             SubtitleData& dat = vi->subDat;
             ts->set_attribute("filename", dat.pth);
