@@ -23,18 +23,20 @@
 
 #include "dvdimport.h"
 
-#include <mgui/render/common.h> // FillEmpty()
-#include <mgui/project/mb-actions.h> // TryAddMedia()
-#include <mgui/gettext.h>
+#include "render/common.h" // FillEmpty()
+#include "project/add.h" // TryAddMediaQuiet()
 
 #include "sdk/treemodel.h"
 #include "sdk/window.h"
 #include "sdk/packing.h"
 #include "sdk/widget.h"
 #include "sdk/browser.h"   // VideoPE
+#include "sdk/player_utils.h"
 #include "dialog.h"
+#include "gettext.h"
 
 #include <mbase/project/table.h>
+#include <mdemux/util.h> // SecToHMS
 #include <mlib/filesystem.h>
 #include <mlib/sdk/logger.h>
 
@@ -69,8 +71,8 @@ ImportData::ImportData(): srcChooser(Gtk::FILE_CHOOSER_ACTION_OPEN),
     // value, lower, upper, step_increment = 1, page_increment = 10, page_size = 0
     previewAdj(0., 0., 0.)
 {
-    SetOutputFormat(thumbPlyr,   fofRGB);
-    SetOutputFormat(previewPlyr, fofRGB);
+    RGBOpen(thumbPlyr);
+    RGBOpen(previewPlyr);
 }
 
 static std::string PageTitle(int pg_num)
@@ -132,7 +134,7 @@ static bool CheckVobSelect(Gtk::TreeIter& itr, bool& has_check)
 static void OnSelVob(ImportData& id)
 {
     bool res = false;
-    ForeachVob(id, bl::bind(&CheckVobSelect, bl::_1, boost::ref(res)));
+    ForeachVob(id, bb::bind(&CheckVobSelect, _1, boost::ref(res)));
     CompleteSelection(id, res);    
 }
 
@@ -142,6 +144,11 @@ static bool OpenVob(VobPtr vob, Mpeg::FwdPlayer& plyr, dvd_reader_t* dvd)
     return plyr.OpenFBuf(strm_buf);
 }
 
+static Project::VideoPE MakeMpegPlayerPE(Mpeg::FwdPlayer& plyr, double time)
+{
+    return Project::VideoPE(bb::bind(&GetRawFrame, time, boost::ref(plyr)));
+}
+
 static bool OnSelectIdle(ImportData& id)
 {
     int num = id.numToThumb++;
@@ -160,7 +167,7 @@ static bool OnSelectIdle(ImportData& id)
             double preview_time = 3.0; // показываем кадр третьей (или первой?) секунды, иначе - середину
             if( preview_time >= tm )
                 preview_time = tm / 2;
-            row[VF().thumbnail] = Project::VideoPE(plyr, preview_time).Make(sz).RWPixbuf();
+            row[VF().thumbnail] = MakeMpegPlayerPE(plyr, preview_time).Make(sz).RWPixbuf();
         }
         else
             LOG_INF << "OpenFBuf() failed: " << plyr.MInfo().ErrorReason() << io::endl;
@@ -214,7 +221,7 @@ static void OnPreparePage(ImportData& id)
         }
         
         ASSERT( id.curPage != ipSELECT_VOBS );
-        id.thumbIdler.ConnectIdle(bl::bind(&OnSelectIdle, boost::ref(id)));
+        id.thumbIdler.ConnectIdle(bb::bind(&OnSelectIdle, boost::ref(id)));
     }
     else
         id.CloseIdlers();
@@ -254,7 +261,7 @@ static ReaderPtr OpenDVD(const std::string& dvd_path, ImportData& id)
 {
     bool is_pal;
     ReaderPtr rd = OpenDVD(dvd_path, is_pal);
-    if( rd && id.addToProject && (is_pal != Project::AData().PalTvSystem()) )
+    if( rd && id.addToProject && (is_pal != Project::IsPALProject()) )
     {
         rd.reset();
         id.errLbl.show();
@@ -289,7 +296,7 @@ bool SetVobSel(Gtk::TreeIter& itr, bool select_all)
 
 static void OnSelectionButton(ImportData& id, bool select_all)
 {
-    ForeachVob(id, bl::bind(SetVobSel, bl::_1, select_all));
+    ForeachVob(id, bb::bind(SetVobSel, _1, select_all));
     CompleteSelection(id, select_all);
 }
 
@@ -321,7 +328,7 @@ static bool UpdatePreview(ImportData& id)
         double tm = GetFrameTime(plyr, (int)id.previewAdj.get_value());
         RefPtr<Gdk::Pixbuf> pix = id.previewImg.get_pixbuf();
 
-        Project::VideoPE(plyr, tm).Fill(pix);
+        MakeMpegPlayerPE(plyr, tm).Fill(pix);
         id.previewImg.queue_draw();
     }
     return false;
@@ -330,7 +337,7 @@ static bool UpdatePreview(ImportData& id)
 static void OnPreviewValueChanged(ImportData& id)
 {
     id.previewIdler.Disconnect();
-    id.previewIdler.ConnectIdle(bl::bind(&UpdatePreview, boost::ref(id)));
+    id.previewIdler.ConnectIdle(bb::bind(&UpdatePreview, boost::ref(id)));
 }
 
 static void OnVobActivate(const Gtk::TreePath& pth, ImportData& id)
@@ -389,7 +396,7 @@ static void PackSelectionButton(Gtk::HBox& hbox, RefPtr<Gtk::SizeGroup> sg, bool
     Gtk::Button& btn = PackStart(hbox, NewManaged<Gtk::Button>(text));
     sg->add_widget(btn);
 
-    btn.signal_clicked().connect(bl::bind(&OnSelectionButton, boost::ref(id), select_all));
+    btn.signal_clicked().connect(bb::bind(&OnSelectionButton, boost::ref(id), select_all));
 }
 
 static double ToPercent(uint32_t written_cnt, uint32_t sector_cnt)
@@ -440,7 +447,7 @@ static void OnApply(ImportData& id)
 
     bool res = Project::HaveFullAccess(dir_path);
     if( !res )
-        MessageBox(BF_("Cant write to folder %1% (check permissions).") % dir_path % bf::stop,
+        MessageBox(BF_("Can't write to folder %1% (check permissions).") % dir_path % bf::stop,
                    Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK);
     else
     {
@@ -479,8 +486,8 @@ static void OnApply(ImportData& id)
                     {
                         io::stream out_strm(fname.c_str(), iof::out);
                         uint32_t written_cnt = sec_arr[i];
-                        ReadFunctor fnr = bl::bind(&CopyFilePartWithProgress, boost::ref(out_strm), 
-                                                   bl::_1, bl::_2, 
+                        ReadFunctor fnr = bb::bind(&CopyFilePartWithProgress, boost::ref(out_strm), 
+                                                   _1, _2,
                                                    boost::ref(written_cnt), sector_cnt, 
                                                    boost::ref(id));
                         //ReadFunctor fnr = MakeWriter(out_strm);
@@ -547,8 +554,8 @@ void ConstructImporter(ImportData& id)
     ast.signal_close().connect(&Gtk::Main::quit);
 
     boost::reference_wrapper<ImportData> ref_id(id);
-    ast.signal_prepare().connect(bl::bind(&OnPreparePage, ref_id));
-    ast.signal_apply().connect(bl::bind(&OnApply, ref_id));
+    ast.signal_prepare().connect(bb::bind(&OnPreparePage, ref_id));
+    ast.signal_apply().connect(bb::bind(&OnApply, ref_id));
 
     for( int i=0; i<ipPAGE_NUM; i++ )
     {
@@ -564,7 +571,7 @@ void ConstructImporter(ImportData& id)
 
                 Gtk::FileChooserWidget& fcw = id.srcChooser;
                 PackFCWPage(vbox, fcw, _("Choose DVD disc, DVD folder or iso image file."));
-                fcw.signal_selection_changed().connect(bl::bind(&OnSelectSource, ref_id));
+                fcw.signal_selection_changed().connect(bb::bind(&OnSelectSource, ref_id));
 
                 // 
                 // От установки фильтра отказался, потому что бывают диски DVD, не открывающиеся на
@@ -598,11 +605,11 @@ void ConstructImporter(ImportData& id)
                 vob_list = Gtk::ListStore::create(GetColumnRecord<VobFields>());
 
                 Gtk::TreeView& view = NewManaged<Gtk::TreeView>(vob_list);
-                view.signal_row_activated().connect(bl::bind(&OnVobActivate, bl::_1, ref_id));
+                view.signal_row_activated().connect(bb::bind(&OnVobActivate, _1, ref_id));
                 // нужно/нет
                 Gtk::CellRendererToggle& sel_rndr = *dynamic_cast<Gtk::CellRendererToggle*>(
                     view.get_column(view.append_column_editable("", VF().selState) - 1)->get_first_cell_renderer());
-                sel_rndr.signal_toggled().connect(bl::bind(&OnSelVob, ref_id));
+                sel_rndr.signal_toggled().connect(bb::bind(&OnSelVob, ref_id));
 
                 // имя
                 Gtk::TreeView::Column& name_cln = NewManaged<Gtk::TreeView::Column>(_("Name"));
@@ -637,7 +644,7 @@ void ConstructImporter(ImportData& id)
                     Gtk::HScale& scl = PackStart(vbox, NewManaged<Gtk::HScale>(id.previewAdj));
                     SetScaleSecondary(scl);
                     id.previewAdj.signal_value_changed().connect(
-                        bl::bind(&OnPreviewValueChanged, ref_id));
+                        bb::bind(&OnPreviewValueChanged, ref_id));
                 }
 
                 // кнопки выбора
@@ -653,7 +660,7 @@ void ConstructImporter(ImportData& id)
                     PackSelectionButton(hbox, sg, false, id);
 
                     ast.signal_prepare().connect(
-                        bl::bind(&OnPrepareSelect, boost::ref(alg), boost::ref(ast)));
+                        bb::bind(&OnPrepareSelect, boost::ref(alg), boost::ref(ast)));
                     alg.show_all();
                 }
             }
@@ -667,7 +674,7 @@ void ConstructImporter(ImportData& id)
                 PackFCWPage(vbox, fcw, _("It is desirable the destination folder to be empty."));
 
                 fcw.signal_selection_changed().connect(
-                    bl::bind(&OnSelectDest, boost::ref(fcw), ref_id));
+                    bb::bind(&OnSelectDest, boost::ref(fcw), ref_id));
             }
             break;
         case ipIMPORT_PROC: 
@@ -687,7 +694,7 @@ void ConstructImporter(ImportData& id)
                 // кнопка отмены
                 Gtk::Alignment& btn_alg = PackStart(vbox, NewManaged<Gtk::Alignment>(1.0, 0.5, 0.1, 1.0));
                 Gtk::Button& btn = Add(btn_alg, *Gtk::manage(new Gtk::Button(Gtk::Stock::STOP)));
-                btn.signal_clicked().connect(bl::bind(&OnImportStop, ref_id));
+                btn.signal_clicked().connect(bb::bind(&OnImportStop, ref_id));
             }
             break;
         case ipEND:
